@@ -33,7 +33,7 @@
 typedef enum {
   GNOME_THEME_TYPE_METATHEME,
   GNOME_THEME_TYPE_ICON,
-  GNOME_THEME_TYPE_REGULAR,
+  GNOME_THEME_TYPE_REGULAR
 } GnomeThemeType;
 
 typedef enum {
@@ -46,7 +46,7 @@ typedef enum {
 typedef enum {
   GNOME_THEME_METACITY = 1 << 0,
   GNOME_THEME_GTK_2 = 1 << 1,
-  GNOME_THEME_GTK_2_KEYBINDING = 1 << 2,
+  GNOME_THEME_GTK_2_KEYBINDING = 1 << 2
 } GnomeThemeElement;
 
 
@@ -81,12 +81,15 @@ struct _GnomeThemeMetaInfo
   gchar *icon_file;
 
   gchar *gtk_theme_name;
+  gchar *gtk_color_scheme;
   gchar *metacity_theme_name;
   gchar *icon_theme_name;
   gchar *sawfish_theme_name;
   gchar *sound_theme_name;
 
   gchar *application_font;
+  gchar *desktop_font;
+  gchar *monospace_font;
   gchar *background_image;
 };
 
