@@ -110,7 +110,7 @@ enum
  */
 static gint double_click_state = DOUBLE_CLICK_TEST_OFF;
 
-/* normalilzation routines */
+/* normalization routines */
 /* All of our scales but double_click are on the range 1->10 as a result, we
  * have a few routines to convert from whatever the gconf key is to our range.
  */
@@ -302,13 +302,6 @@ cursor_size_from_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 	return new_value;
 }
 
-/* Retrieve legacy settings */
-
-static void
-get_legacy_settings (void) 
-{
-}
-
 /* Double Click handling */
 
 struct test_data_t 
@@ -421,51 +414,6 @@ left_handed_toggle_cb (GConfPropertyEditor *peditor, const gchar *key, const GCo
 	}
 }
 
-static gchar *
-read_cursor_font (void)
-{
-	DIR *dir;
-	gchar *dir_name;
-	struct dirent *file_dirent;
-
-	dir_name = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".gnome2/share/cursor-fonts", NULL);
-	if (! g_file_test (dir_name, G_FILE_TEST_EXISTS))
-		return NULL;
-
-	dir = opendir (dir_name);
-  
-	while ((file_dirent = readdir (dir)) != NULL) {
-		struct stat st;
-		gchar *link_name;
-
-		link_name = g_build_filename (dir_name, file_dirent->d_name, NULL);
-		if (lstat (link_name, &st)) {
-			g_free (link_name);
-			continue;
-		}
-	  
-		if (S_ISLNK (st.st_mode)) {
-			gint length;
-			gchar target[256];
-
-			length = readlink (link_name, target, 255);
-			if (length > 0) {
-				gchar *retval;
-				target[length] = '\0';
-				retval = g_strdup (target);
-				g_free (link_name);
-				closedir (dir);
-				return retval;
-			}
-			
-		}
-		g_free (link_name);
-	}
-	g_free (dir_name);
-	closedir (dir);
-	return NULL;
-}
-
 #ifdef HAVE_XCURSOR
 static void
 cursor_theme_changed (GConfClient *client,
@@ -574,6 +522,53 @@ cursor_font_changed (GConfClient *client,
 	g_free (cursor_font);
 	g_free (cursor_text);
 }
+
+static gchar *
+read_cursor_font (void)
+{
+	DIR *dir;
+	gchar *dir_name;
+	struct dirent *file_dirent;
+
+	dir_name = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".gnome2/share/cursor-fonts", NULL);
+	if (! g_file_test (dir_name, G_FILE_TEST_EXISTS)) {
+		g_free (dir_name);
+		return NULL;
+	}
+
+	dir = opendir (dir_name);
+  
+	while ((file_dirent = readdir (dir)) != NULL) {
+		struct stat st;
+		gchar *link_name;
+
+		link_name = g_build_filename (dir_name, file_dirent->d_name, NULL);
+		if (lstat (link_name, &st)) {
+			g_free (link_name);
+			continue;
+		}
+	  
+		if (S_ISLNK (st.st_mode)) {
+			gint length;
+			gchar target[256];
+
+			length = readlink (link_name, target, 255);
+			if (length > 0) {
+				gchar *retval;
+				target[length] = '\0';
+				retval = g_strdup (target);
+				g_free (link_name);
+				closedir (dir);
+				return retval;
+			}
+			
+		}
+		g_free (link_name);
+	}
+	g_free (dir_name);
+	closedir (dir);
+	return NULL;
+}
 #endif /* !HAVE_XCURSOR */
 
 static void
@@ -674,6 +669,8 @@ populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 
 	gchar **iterator = NULL;
 	gchar **paths = NULL;
+	gboolean has_default = FALSE;
+	GtkTreeIter iter;
 
 	GConfClient* client = gconf_client_get_default();
 	GtkListStore* store = GTK_LIST_STORE(gtk_tree_model_sort_get_model(model));
@@ -692,7 +689,7 @@ populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 		gchar*       fname = NULL;
 		GDir*        folder = NULL;
 		const gchar* name;
-		
+
 		if(strchr(*iterator, '%')) {
 			fname = g_strdup_printf(*iterator, g_getenv("HOME"));
 		} else {
@@ -700,26 +697,25 @@ populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 		}
 
 		folder = g_dir_open(fname, 0, NULL);
-		
+
 		while(folder && (name = g_dir_read_name(folder))) {
 			gchar* cursor_dir = g_strdup_printf("%s/%s/cursors/", fname, name);
 			XcursorImage* cursor;
 			gint sizes[] = { 12, 16, 24, 32, 36, 48, 0 };
 			gint i;
-			GtkTreeIter iter;
-			
+
 			if(!g_file_test(cursor_dir, G_FILE_TEST_EXISTS)) {
 				g_free(cursor_dir);
 				continue;
 			}
-			
+
 			for (i = 0; sizes[i] != 0; i++) {
 				cursor = XcursorLibraryLoadImage("left_ptr", name, sizes[i]);
 				if (cursor && cursor->size != sizes[i]) {
 					XcursorImageDestroy (cursor);
 					cursor = NULL;
 				}
-				
+
 				if(cursor) {
 					GdkPixbuf* pixbuf = gdk_pixbuf_from_xcursor_image(cursor);
 
@@ -732,7 +728,7 @@ populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 								   COLUMN_SIZE, sizes[i],
 								   -1);
 						g_object_unref(pixbuf);
-						
+
 						if(current_theme != NULL && !strcmp(current_theme, name) &&
 							current_size == sizes[i]) {
 							GtkTreeIter sort_iter;
@@ -742,10 +738,14 @@ populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 							gtk_tree_selection_select_iter(selection,
 										       &sort_iter);
 						}
+
+						if(G_LIKELY(!has_default) && !strcmp(name, "default")) {
+							has_default = TRUE;
+						}
 					}
 				}
 			}
-			
+
 			g_free(cursor_dir);
 		}
 
@@ -754,32 +754,40 @@ populate_tree_model(GtkTreeModelSort* model, GtkTreeSelection* selection) {
 		}
 		g_free(fname);
 	}
-	
+	g_strfreev (paths);
+
+	if(G_LIKELY(!has_default)) {
+		gtk_list_store_append(store, &iter);
+		gtk_list_store_set(store, &iter,
+				   COLUMN_PIXBUF, NULL,
+				   COLUMN_TEXT, _("Default Pointer"),
+				   COLUMN_FONT_PATH, "default",
+				   COLUMN_SIZE, 18,
+				   -1);
+	}
+
 	g_free(current_theme);
 
-	if (xpaths != NULL) {
-		g_strfreev (paths);
-	}
 #else /* !HAVE_XCURSOR */
 	gchar* cursor_font;
 	static const gchar* builtins[][5] = {
 		{
 			"gnome/cursor-fonts/cursor-normal.pcf",
-		       	N_("Default Pointer"),
-		       	N_("Default Pointer - Current"),
-		       	N_("The default pointer that ships with X"),
+			N_("Default Pointer"),
+			N_("Default Pointer - Current"),
+			N_("The default pointer that ships with X"),
 			"mouse-cursor-normal.png"
 		}, {
 			"gnome/cursor-fonts/cursor-white.pcf",
-		      	N_("White Pointer"),
-		     	N_("White Pointer - Current"),
-		     	N_("The default pointer inverted"),
+			N_("White Pointer"),
+			N_("White Pointer - Current"),
+			N_("The default pointer inverted"),
 			"mouse-cursor-white.png"
 		}, {
 			"gnome/cursor-fonts/cursor-large.pcf",
-		      	N_("Large Pointer"),
-		     	N_("Large Pointer - Current"),
-		     	N_("Large version of normal pointer"),
+			N_("Large Pointer"),
+			N_("Large Pointer - Current"),
+			N_("Large version of normal pointer"),
 			"mouse-cursor-normal-large.png"
 		}, {
 			"gnome/cursor-fonts/cursor-large-white.pcf",
@@ -856,10 +864,7 @@ setup_dialog (GladeXML *dialog, GConfChangeSet *changeset)
 	GtkWidget         *tree_view;
 	GtkTreeSelection  *selection;
 	GtkTreeModel      *model;
-	GtkCellRenderer   *renderer;
-	GtkTreeViewColumn *column;
 	GConfValue        *value;
-	gchar             *cursor_font;
 	gchar             *message;
 
 	GConfClient       *client = gconf_client_get_default ();
@@ -894,31 +899,25 @@ setup_dialog (GladeXML *dialog, GConfChangeSet *changeset)
 
 	/* Cursors page */
 	tree_view = WID ("cursor_tree");
-	cursor_font = read_cursor_font ();
-
 	model = (GtkTreeModel *) gtk_list_store_new (N_COLUMNS, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT);
 	model = (GtkTreeModel *) gtk_tree_model_sort_new_with_model (model);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (tree_view),
 				 model);
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
-	column = gtk_tree_view_column_new ();
-	renderer = gtk_cell_renderer_pixbuf_new ();
-	gtk_tree_view_column_pack_start (column, renderer, FALSE);
-	gtk_tree_view_column_set_attributes (column, renderer,
-					     "pixbuf", COLUMN_PIXBUF,
-					     NULL);
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes (column, renderer,
-					     "markup", COLUMN_TEXT,
-					     NULL);
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view), -1,
+						     "Preview", gtk_cell_renderer_pixbuf_new (),
+						     "pixbuf", COLUMN_PIXBUF,
+						     NULL);
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view), -1,
+						     "Name", gtk_cell_renderer_text_new (),
+						     "markup", COLUMN_TEXT,
+						     NULL);
 
 	/* Add the cursors */
 	populate_tree_model(GTK_TREE_MODEL_SORT(model), selection);
 	g_signal_connect (G_OBJECT (selection), "changed", G_CALLBACK (cursor_changed), NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column);
-	
+
 	gconf_peditor_new_boolean
 		(changeset, "/desktop/gnome/peripherals/mouse/locate_pointer", WID ("locate_pointer_toggle"), NULL);
 
@@ -976,7 +975,9 @@ create_dialog (void)
 	/* register the custom type */
 	(void) mouse_capplet_check_button_get_type ();
 
-	dialog = glade_xml_new (GNOMECC_DATA_DIR "/interfaces/gnome-mouse-properties.glade", "mouse_properties_dialog", NULL);
+	dialog = glade_xml_new (GNOMECC_GLADE_DIR "/gnome-mouse-properties.glade", "mouse_properties_dialog", NULL);
+	if (!dialog)
+		return NULL;
 
 	text = g_strdup_printf ("<b>%s</b>", _("Pointer Theme"));
 	gtk_label_set_markup (GTK_LABEL (WID ("cursor_category_label")), text);
@@ -1016,27 +1017,19 @@ dialog_response_cb (GtkDialog *dialog, gint response_id, GConfChangeSet *changes
 int
 main (int argc, char **argv)
 {
+	GnomeProgram   *program;
 	GConfClient    *client;
-	GConfChangeSet *changeset;
 	GladeXML       *dialog;
 	GtkWidget      *dialog_win;
 
-	static gboolean get_legacy;
-	static struct poptOption cap_options[] = {
-		{ "get-legacy", '\0', POPT_ARG_NONE, &get_legacy, 0,
-		  N_("Retrieve and store legacy settings"), NULL },
-		{ NULL, '\0', 0, NULL, 0, NULL, NULL }
-	};
-
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("gnome-mouse-properties", VERSION,
-			    LIBGNOMEUI_MODULE, argc, argv,
-			    GNOME_PARAM_POPT_TABLE, cap_options,
-			    GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
-			    NULL);
+	program = gnome_program_init ("gnome-mouse-properties", VERSION,
+				      LIBGNOMEUI_MODULE, argc, argv,
+				      GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
+				      NULL);
 
 	capplet_init_stock_icons ();
 
@@ -1046,22 +1039,24 @@ main (int argc, char **argv)
 	gconf_client_add_dir (client, "/desktop/gnome/peripherals/mouse", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 	g_object_unref (client);
 
-	if (get_legacy) {
-		get_legacy_settings ();
-	} else {
-		changeset = NULL;
-		dialog = create_dialog ();
-		setup_dialog (dialog, changeset);
+	dialog = create_dialog ();
+
+	if (dialog) {
+		setup_dialog (dialog, NULL);
 
 		dialog_win = WID ("mouse_properties_dialog");
 		g_signal_connect (dialog_win, "response",
-				  G_CALLBACK (dialog_response_cb), changeset);
+				  G_CALLBACK (dialog_response_cb), NULL);
 
 		capplet_set_icon (dialog_win, "gnome-dev-mouse-optical");
 		gtk_widget_show (dialog_win);
 
 		gtk_main ();
+
+		g_object_unref (dialog);
 	}
 
+	g_object_unref (program);
+
 	return 0;
 }
